from distutils.core import setup

setup(
    version='0.13.3',
    name='qweborf',
    author="Salvo 'LtWorf' Tomaselli",
    author_email='tiposchi@tiscali.it',
    maintainer="Salvo 'LtWorf' Tomaselli",
    maintainer_email='tiposchi@tiscali.it',
    url='http://ltworf.github.io/weborf/',
    license='GPL3',
    packages=('qweborf',),
    )

